@@ -77,13 +77,6 @@ from mx_platform_python.model.o_auth_window_response import OAuthWindowResponse
 from mx_platform_python.model.o_auth_window_response_body import OAuthWindowResponseBody
 from mx_platform_python.model.option_response import OptionResponse
 from mx_platform_python.model.pagination_response import PaginationResponse
-from mx_platform_python.model.partner_account_response import PartnerAccountResponse
-from mx_platform_python.model.partner_account_response_body import PartnerAccountResponseBody
-from mx_platform_python.model.partner_authorization_code_request import PartnerAuthorizationCodeRequest
-from mx_platform_python.model.partner_authorization_code_request_body import PartnerAuthorizationCodeRequestBody
-from mx_platform_python.model.partner_authorization_code_response import PartnerAuthorizationCodeResponse
-from mx_platform_python.model.partner_authorization_code_response_body import PartnerAuthorizationCodeResponseBody
-from mx_platform_python.model.partner_token_response_body import PartnerTokenResponseBody
 from mx_platform_python.model.statement_response import StatementResponse
 from mx_platform_python.model.statement_response_body import StatementResponseBody
 from mx_platform_python.model.statements_response_body import StatementsResponseBody
